function [x,fval] = optimSub(a,b,c,d,e)
%[X,FVAL] = optimSub(A,B,C,D,E) solves an unconstrained
%   optimization problem in two dimension using subfunctions
%
%   Example
%  % 1) Smooth objective function
%     [x, fval ] = optimSub(3,2,1,0,0)
%
%  % 2) Non-smooth objective function
%     [x, fval ] = optimSub(3,2,1,5,0)
%
%  % 3) Stochastic objective function
%     [x, fval ] = optimSub(3,2,1,0,2)
%
%  % 4) Non-smooth stochastic objective function
%     [x, fval ] = optimSub(3,2,1,6,3)

    if nargin < 5
        %default values
        a = 3; b = 2; c = 1; d = 6; e = 0;
    end
    
    %Settings
    range = [-10 10; -10 10];
    x0 = [-5,9];     % Starting guess    
    options = optimoptions('fminunc','Display','off',...
                'algorithm','quasi-newton',...
                'OutputFcn',@(x,optimvalues,state)myoutputfcn(x,optimvalues,state,a,b,c,d,e,range));
    
    %Package the objective function into an anonymous function that
    %contains the static variables but receives x.
    [x, fval] = fminunc(@(x)objfun(x,a,b,c,d,e),x0,options);

end

function f = objfun(x,a,b,c,d,e)
% Nonlinear objective function
    f = a*x(:,1).^2 + b*x(:,1).*x(:,2) + ...
        c*x(:,2).^2 + d*abs(x(:,2) - x(:,1))+ e*randn;

end

function stop = myoutputfcn(x,optimvalues,state,a,b,c,d,e,range)
% Function that updates plot    
    stop = false;
    switch state
        case 'init'
            clf
            plotobjective(@(x,range)objfun(x,a,b,c,d,e),range);
        case 'iter'
            plot3(x(1),x(2),optimvalues.fval+2, ...
                'ro','MarkerFaceColor','r', ...
                'MarkerSize',6)
            pause(0.5);
        case 'done'
            plot3(x(1),x(2),optimvalues.fval+5, ...
                'y*','MarkerFaceColor','y', ...
                'MarkerSize',10)
        
    end

end